==> php54-owncloud-8.0.2.tgz: share/owncloud/lib/l10n/pl.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nie można zapisać do katalogu \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Można to zwykle rozwiązać przez dodanie serwerowi www uprawnień zapisu do katalogu config.",
    "See %s" : "Zobacz %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Można to zwykle rozwiązać przez %sdodanie serwerowi www uprawnień zapisu do katalogu config%s.",
    "Sample configuration detected" : "Wykryto przykładową konfigurację",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Wykryto skopiowanie przykładowej konfiguracji. To może popsuć Twoją instalację i nie jest wspierane. Proszę przeczytać dokumentację przed dokonywaniem zmian w config.php",
    "PHP %s or higher is required." : "PHP %s lub wyższe jest wymagane.",
    "Following databases are supported: %s" : "Obsługiwane są następujące bazy danych: %s",
    "The library %s is not available." : "Biblioteka %s nie jest dostępna.",
    "Following platforms are supported: %s" : "Obsługiwane są następujące platformy: %s",
    "Help" : "Pomoc",
    "Personal" : "Osobiste",
    "Settings" : "Ustawienia",
    "Users" : "Użytkownicy",
    "Admin" : "Administrator",
    "Recommended" : "Polecane",
    "App \\\"%s\\\" can't be installed because it is not compatible with this version of ownCloud." : "Aplikacja  \\\"%s\\\" nie może zostać zainstalowana ponieważ nie jest kompatybilna z tą wersją ownCloud.",
    "No app name specified" : "Nie określono nazwy aplikacji",
    "Unknown filetype" : "Nieznany typ pliku",
    "Invalid image" : "Błędne zdjęcie",
    "today" : "dziś",
    "yesterday" : "wczoraj",
    "_%n day ago_::_%n days ago_" : ["%d dzień temu","%n dni temu","%n dni temu"],
    "last month" : "w zeszłym miesiącu",
    "_%n month ago_::_%n months ago_" : ["%n miesiąc temu","%n miesięcy temu","%n miesięcy temu"],
    "last year" : "w zeszłym roku",
    "_%n year ago_::_%n years ago_" : ["%n rok temu","%n lata temu","%n lat temu"],
    "_%n hour ago_::_%n hours ago_" : ["%n godzinę temu","%n godzin temu","%n godzin temu"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minute temu","%n minut temu","%n minut temu"],
    "seconds ago" : "sekund temu",
    "Database Error" : "Błąd bazy danych",
    "Please contact your system administrator." : "Proszę skontaktować się z administratorem sytemu.",
    "web services under your control" : "Kontrolowane serwisy",
    "App directory already exists" : "Katalog aplikacji już isnieje",
    "Can't create app folder. Please fix permissions. %s" : "Nie mogę utworzyć katalogu aplikacji. Proszę popraw uprawnienia. %s",
    "No source specified when installing app" : "Nie określono źródła  podczas instalacji aplikacji",
    "No href specified when installing app from http" : "Nie określono linku skąd aplikacja ma być zainstalowana",
    "No path specified when installing app from local file" : "Nie określono lokalnego pliku z którego miała być instalowana aplikacja",
    "Archives of type %s are not supported" : "Typ archiwum %s nie jest obsługiwany",
    "Failed to open archive when installing app" : "Nie udało się otworzyć archiwum podczas instalacji aplikacji",
    "App does not provide an info.xml file" : "Aplikacja nie posiada pliku info.xml",
    "App can't be installed because of not allowed code in the App" : "Aplikacja nie może być zainstalowany ponieważ nie dopuszcza kod w aplikacji",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikacja nie może zostać zainstalowana ponieważ jest niekompatybilna z tą wersja ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikacja nie może być zainstalowana ponieważ true tag nie jest <shipped>true</shipped> , co nie jest dozwolone dla aplikacji nie wysłanych",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Nie można zainstalować aplikacji, ponieważ w wersji info.xml/version nie jest taka sama, jak wersja z app store",
    "Application is not enabled" : "Aplikacja nie jest włączona",
    "Authentication error" : "Błąd uwierzytelniania",
    "Token expired. Please reload page." : "Token wygasł. Proszę ponownie załadować stronę.",
    "Unknown user" : "Nieznany użytkownik",
    "%s enter the database username." : "%s wpisz nazwę użytkownika do  bazy",
    "%s enter the database name." : "%s wpisz nazwę bazy.",
    "%s you may not use dots in the database name" : "%s nie można używać kropki w nazwie bazy danych",
    "MS SQL username and/or password not valid: %s" : "Nazwa i/lub hasło serwera MS SQL jest niepoprawne: %s.",
    "You need to enter either an existing account or the administrator." : "Należy wprowadzić istniejące konto użytkownika lub  administratora.",
    "MySQL/MariaDB username and/or password not valid" : "Użytkownik i/lub hasło do MySQL/MariaDB są niepoprawne",
    "DB Error: \"%s\"" : "Błąd DB: \"%s\"",
    "Offending command was: \"%s\"" : "Niepoprawna komenda: \"%s\"",
    "MySQL/MariaDB user '%s'@'localhost' exists already." : "Użytkownik '%s'@'localhost' MySQL/MariaDB już istnieje.",
    "Drop this user from MySQL/MariaDB" : "Usuń tego użytkownika z MySQL/MariaDB",
    "MySQL/MariaDB user '%s'@'%%' already exists" : "Użytkownik  '%s'@'%%' MySQL/MariaDB już istnieje.",
    "Drop this user from MySQL/MariaDB." : "Usuń tego użytkownika z MySQL/MariaDB",
    "Oracle connection could not be established" : "Nie można ustanowić połączenia z bazą Oracle",
    "Oracle username and/or password not valid" : "Oracle: Nazwa użytkownika i/lub hasło jest niepoprawne",
    "Offending command was: \"%s\", name: %s, password: %s" : "Niepoprawne polecania:  \"%s\", nazwa: %s, hasło: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL: Nazwa użytkownika i/lub hasło jest niepoprawne",
    "Set an admin username." : "Ustaw nazwę administratora.",
    "Set an admin password." : "Ustaw hasło administratora.",
    "Can't create or write into the data directory %s" : "Nie można tworzyć ani zapisywać w katalogu %s",
    "%s shared »%s« with you" : "%s Współdzielone »%s« z tobą",
    "Sharing %s failed, because the file does not exist" : "Wspóldzielenie %s nie powiodło się. ponieważ plik nie istnieje",
    "You are not allowed to share %s" : "Nie masz uprawnień aby udostępnić %s",
    "Sharing %s failed, because the user %s is the item owner" : "Współdzielenie %s nie powiodło się, ponieważ użytkownik %s jest właścicielem elementu",
    "Sharing %s failed, because the user %s does not exist" : "Współdzielenie %s nie powiodło się, ponieważ użytkownik %s nie istnieje",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Współdzielenie %s nie powiodło się, ponieważ użytkownik %s nie jest członkiem żadnej grupy której członkiem jest %s",
    "Sharing %s failed, because this item is already shared with %s" : "Współdzielenie %s nie powiodło się, ponieważ element jest już współdzielony z %s",
    "Sharing %s failed, because the group %s does not exist" : "Współdzielenie %s nie powiodło się, ponieważ grupa %s nie istnieje",
    "Sharing %s failed, because %s is not a member of the group %s" : "Współdzielenie %s nie powiodło się, ponieważ %s nie jest członkiem grupy %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Musisz zapewnić hasło aby utworzyć link publiczny, dozwolone są tylko linki chronione",
    "Sharing %s failed, because sharing with links is not allowed" : "Współdzielenie %s nie powiodło się, ponieważ współdzielenie z linkami nie jest dozwolone",
    "Share type %s is not valid for %s" : "Typ udziału %s nie jest właściwy dla %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Ustawienie uprawnień dla %s nie powiodło się, ponieważ uprawnienia wykraczają poza przydzielone %s",
    "Setting permissions for %s failed, because the item was not found" : "Ustawienie uprawnień dla %s nie powiodło się, ponieważ element nie został znaleziony",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nie można ustawić daty wygaśnięcia. Udziały nie mogą wygasać później niż %s od momentu udostępnienia",
    "Cannot set expiration date. Expiration date is in the past" : "Nie można ustawić daty wygaśnięcia. Data wygaśnięcia jest w przeszłości.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Zaplecze do współdzielenia %s musi implementować interfejs OCP\\Share_Backend",
    "Sharing backend %s not found" : "Zaplecze %s do współdzielenia nie zostało znalezione",
    "Sharing backend for %s not found" : "Zaplecze do współdzielenia %s nie zostało znalezione",
    "Sharing %s failed, because the user %s is the original sharer" : "Współdzielenie %s nie powiodło się, ponieważ użytkownik %s jest udostępniającym",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Współdzielenie %s nie powiodło się, ponieważ uprawnienia przekraczają te udzielone %s",
    "Sharing %s failed, because resharing is not allowed" : "Współdzielenie %s nie powiodło się, ponieważ ponowne współdzielenie nie jest dozwolone",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Współdzielenie %s nie powiodło się, ponieważ zaplecze współdzielenia dla %s nie mogło znaleźć jego źródła",
    "Sharing %s failed, because the file could not be found in the file cache" : "Współdzielenie %s nie powiodło się, ponieważ plik nie może zostać odnaleziony w buforze plików",
    "Could not find category \"%s\"" : "Nie można odnaleźć kategorii \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "W nazwach użytkowników dozwolone są wyłącznie następujące znaki: \"a-z\", \"A-Z\", \"0-9\", oraz \"_.@-\"",
    "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
    "A valid password must be provided" : "Należy podać prawidłowe hasło",
    "The username is already being used" : "Ta nazwa użytkownika jest już używana",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Brak sterowników bazy danych (sqlite, mysql or postgresql).",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Problemy z uprawnieniami można zwykle naprawić  przez %sdodanie serwerowi www uprawnień zapisu do katalogu głównego%s.",
    "Cannot write into \"config\" directory" : "Nie można zapisać do katalogu \"config\"",
    "Cannot write into \"apps\" directory" : "Nie można zapisać do katalogu \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Można to zwykle rozwiązać przez %sdodanie serwerowi www uprawnień zapisu do katalogu apps%s lub wyłączenie appstore w pliku konfiguracyjnym.",
    "Cannot create \"data\" directory (%s)" : "Nie można utworzyć katalogu \"data\" (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Można to zwykle rozwiązać przez <a href=\"%s\" target=\"_blank\">dodanie serwerowi www uprawnień zapisu do katalogu głównego</a>.",
    "Setting locale to %s failed" : "Nie udało się zmienić języka na %s",
    "Please install one of these locales on your system and restart your webserver." : "Proszę zainstalować jedno z poniższych locale w Twoim systemie i uruchomić ponownie serwer www.",
    "Please ask your server administrator to install the module." : "Proszę poproś administratora serwera aby zainstalował ten moduł.",
    "PHP module %s not installed." : "Moduł PHP %s nie jest zainstalowany.",
    "Please ask your server administrator to update PHP to the latest version. Your PHP version is no longer supported by ownCloud and the PHP community." : "Proszę poproś administratora serwera aby zaktualizował PHP do najnowszej wersji. Twoja wersja PHP nie jest już dłużej wspierana przez ownCloud i społeczność PHP.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Wygląda na to, że ustawienia PHP ucinają bloki wklejonych dokumentów. To sprawi, że niektóre wbudowane aplikacje będą niedostępne.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dzieje się tak prawdopodobnie przez cache lub akcelerator taki jak Zend OPcache lub eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Moduły PHP zostały zainstalowane, ale nadal brakuje ich na liście?",
    "Please ask your server administrator to restart the web server." : "Poproś administratora serwera o restart serwera www.",
    "PostgreSQL >= 9 required" : "Wymagany PostgreSQL >= 9",
    "Please upgrade your database version" : "Uaktualnij wersję bazy danych",
    "Error occurred while checking PostgreSQL version" : "Wystąpił błąd podczas sprawdzania wersji PostgreSQL",
    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Upewnij się, że PostgreSQL jest w wersji co najmniej 9 lub sprawdź log by uzyskać więcej informacji na temat błędu",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, żeby ukryć zawartość katalogu przed innymi użytkownikami.",
    "Data directory (%s) is readable by other users" : "Katalog danych (%s) jest możliwy do odczytania przez innych użytkowników",
    "Data directory (%s) is invalid" : "Katalog danych (%s) jest nieprawidłowy",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Sprawdź, czy katalog danych zawiera plik \".ocdata\".",
    "Could not obtain lock type %d on \"%s\"." : "Nie można uzyskać blokady typu %d na \"%s\"."
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/lib/l10n/pl.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nie można zapisać do katalogu \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Można to zwykle rozwiązać przez dodanie serwerowi www uprawnień zapisu do katalogu config.",
    "See %s" : "Zobacz %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Można to zwykle rozwiązać przez %sdodanie serwerowi www uprawnień zapisu do katalogu config%s.",
    "Sample configuration detected" : "Wykryto przykładową konfigurację",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Wykryto skopiowanie przykładowej konfiguracji. To może popsuć Twoją instalację i nie jest wspierane. Proszę przeczytać dokumentację przed dokonywaniem zmian w config.php",
    "PHP %s or higher is required." : "PHP %s lub wyższe jest wymagane.",
    "PHP with a version lower than %s is required." : "Wersja PHP jest niższa niż %s, która jest wymagana.",
    "Following databases are supported: %s" : "Obsługiwane są następujące bazy danych: %s",
    "The command line tool %s could not be found" : "Narzędzie konsoli %s nie zostało znalezione",
    "The library %s is not available." : "Biblioteka %s nie jest dostępna.",
    "Library %s with a version higher than %s is required - available version %s." : "Biblioteka %s w wersji wyższej niż %s, która jest wymagana - dostępna wersja %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Biblioteka w wersji %s jest niższa niż %s, która jest wymagana - dostępna wersja %s.",
    "Following platforms are supported: %s" : "Obsługiwane są następujące platformy: %s",
    "ownCloud %s or higher is required." : "ownCloud %s jest w wersji wyższej niż wymagana.",
    "ownCloud with a version lower than %s is required." : "ownCloud jest w wersji niższej niż wymagana wersja %s",
    "Help" : "Pomoc",
    "Personal" : "Osobiste",
    "Users" : "Użytkownicy",
    "Admin" : "Administrator",
    "Recommended" : "Polecane",
    "No app name specified" : "Nie określono nazwy aplikacji",
    "Unknown filetype" : "Nieznany typ pliku",
    "Invalid image" : "Błędne zdjęcie",
    "today" : "dziś",
    "yesterday" : "wczoraj",
    "_%n day ago_::_%n days ago_" : ["%d dzień temu","%n dni temu","%n dni temu"],
    "last month" : "w zeszłym miesiącu",
    "_%n month ago_::_%n months ago_" : ["%n miesiąc temu","%n miesięcy temu","%n miesięcy temu"],
    "last year" : "w zeszłym roku",
    "_%n year ago_::_%n years ago_" : ["%n rok temu","%n lata temu","%n lat temu"],
    "_%n hour ago_::_%n hours ago_" : ["%n godzinę temu","%n godzin temu","%n godzin temu"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minute temu","%n minut temu","%n minut temu"],
    "seconds ago" : "sekund temu",
    "web services under your control" : "Kontrolowane serwisy",
    "App directory already exists" : "Katalog aplikacji już isnieje",
    "Can't create app folder. Please fix permissions. %s" : "Nie mogę utworzyć katalogu aplikacji. Proszę popraw uprawnienia. %s",
    "No source specified when installing app" : "Nie określono źródła  podczas instalacji aplikacji",
    "No href specified when installing app from http" : "Nie określono linku skąd aplikacja ma być zainstalowana",
    "No path specified when installing app from local file" : "Nie określono lokalnego pliku z którego miała być instalowana aplikacja",
    "Archives of type %s are not supported" : "Typ archiwum %s nie jest obsługiwany",
    "Failed to open archive when installing app" : "Nie udało się otworzyć archiwum podczas instalacji aplikacji",
    "App does not provide an info.xml file" : "Aplikacja nie posiada pliku info.xml",
    "App can't be installed because of not allowed code in the App" : "Aplikacja nie może być zainstalowany ponieważ nie dopuszcza kod w aplikacji",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikacja nie może zostać zainstalowana ponieważ jest niekompatybilna z tą wersja ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikacja nie może być zainstalowana ponieważ true tag nie jest <shipped>true</shipped> , co nie jest dozwolone dla aplikacji nie wysłanych",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Nie można zainstalować aplikacji, ponieważ w wersji info.xml/version nie jest taka sama, jak wersja z app store",
    "Application is not enabled" : "Aplikacja nie jest włączona",
    "Authentication error" : "Błąd uwierzytelniania",
    "Token expired. Please reload page." : "Token wygasł. Proszę ponownie załadować stronę.",
    "Unknown user" : "Nieznany użytkownik",
    "%s enter the database username." : "%s wpisz nazwę użytkownika do  bazy",
    "%s enter the database name." : "%s wpisz nazwę bazy.",
    "%s you may not use dots in the database name" : "%s nie można używać kropki w nazwie bazy danych",
    "MS SQL username and/or password not valid: %s" : "Nazwa i/lub hasło serwera MS SQL jest niepoprawne: %s.",
    "You need to enter either an existing account or the administrator." : "Należy wprowadzić istniejące konto użytkownika lub  administratora.",
    "MySQL/MariaDB username and/or password not valid" : "Użytkownik i/lub hasło do MySQL/MariaDB są niepoprawne",
    "DB Error: \"%s\"" : "Błąd DB: \"%s\"",
    "Offending command was: \"%s\"" : "Niepoprawna komenda: \"%s\"",
    "MySQL/MariaDB user '%s'@'localhost' exists already." : "Użytkownik '%s'@'localhost' MySQL/MariaDB już istnieje.",
    "Drop this user from MySQL/MariaDB" : "Usuń tego użytkownika z MySQL/MariaDB",
    "MySQL/MariaDB user '%s'@'%%' already exists" : "Użytkownik  '%s'@'%%' MySQL/MariaDB już istnieje.",
    "Drop this user from MySQL/MariaDB." : "Usuń tego użytkownika z MySQL/MariaDB",
    "Oracle connection could not be established" : "Nie można ustanowić połączenia z bazą Oracle",
    "Oracle username and/or password not valid" : "Oracle: Nazwa użytkownika i/lub hasło jest niepoprawne",
    "Offending command was: \"%s\", name: %s, password: %s" : "Niepoprawne polecania:  \"%s\", nazwa: %s, hasło: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL: Nazwa użytkownika i/lub hasło jest niepoprawne",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie jest wspierany i %s nie będzie działać poprawnie na tej platformie. Używasz na własne ryzyko!",
    "For the best results, please consider using a GNU/Linux server instead." : "Aby uzyskać najlepsze rezultaty, rozważ w to miejsce użycie serwera GNU/Linux.",
    "Set an admin username." : "Ustaw nazwę administratora.",
    "Set an admin password." : "Ustaw hasło administratora.",
    "Can't create or write into the data directory %s" : "Nie można tworzyć ani zapisywać w katalogu %s",
    "%s shared »%s« with you" : "%s Współdzielone »%s« z tobą",
    "Sharing %s failed, because the file does not exist" : "Wspóldzielenie %s nie powiodło się. ponieważ plik nie istnieje",
    "You are not allowed to share %s" : "Nie masz uprawnień aby udostępnić %s",
    "Sharing %s failed, because the user %s is the item owner" : "Współdzielenie %s nie powiodło się, ponieważ użytkownik %s jest właścicielem elementu",
    "Sharing %s failed, because the user %s does not exist" : "Współdzielenie %s nie powiodło się, ponieważ użytkownik %s nie istnieje",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Współdzielenie %s nie powiodło się, ponieważ użytkownik %s nie jest członkiem żadnej grupy której członkiem jest %s",
    "Sharing %s failed, because this item is already shared with %s" : "Współdzielenie %s nie powiodło się, ponieważ element jest już współdzielony z %s",
    "Sharing %s failed, because the group %s does not exist" : "Współdzielenie %s nie powiodło się, ponieważ grupa %s nie istnieje",
    "Sharing %s failed, because %s is not a member of the group %s" : "Współdzielenie %s nie powiodło się, ponieważ %s nie jest członkiem grupy %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Musisz zapewnić hasło aby utworzyć link publiczny, dozwolone są tylko linki chronione",
    "Sharing %s failed, because sharing with links is not allowed" : "Współdzielenie %s nie powiodło się, ponieważ współdzielenie z linkami nie jest dozwolone",
    "Share type %s is not valid for %s" : "Typ udziału %s nie jest właściwy dla %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Ustawienie uprawnień dla %s nie powiodło się, ponieważ uprawnienia wykraczają poza przydzielone %s",
    "Setting permissions for %s failed, because the item was not found" : "Ustawienie uprawnień dla %s nie powiodło się, ponieważ element nie został znaleziony",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nie można ustawić daty wygaśnięcia. Udziały nie mogą wygasać później niż %s od momentu udostępnienia",
    "Cannot set expiration date. Expiration date is in the past" : "Nie można ustawić daty wygaśnięcia. Data wygaśnięcia jest w przeszłości.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Zaplecze do współdzielenia %s musi implementować interfejs OCP\\Share_Backend",
    "Sharing backend %s not found" : "Zaplecze %s do współdzielenia nie zostało znalezione",
    "Sharing backend for %s not found" : "Zaplecze do współdzielenia %s nie zostało znalezione",
    "Sharing %s failed, because the user %s is the original sharer" : "Współdzielenie %s nie powiodło się, ponieważ użytkownik %s jest udostępniającym",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Współdzielenie %s nie powiodło się, ponieważ uprawnienia przekraczają te udzielone %s",
    "Sharing %s failed, because resharing is not allowed" : "Współdzielenie %s nie powiodło się, ponieważ ponowne współdzielenie nie jest dozwolone",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Współdzielenie %s nie powiodło się, ponieważ zaplecze współdzielenia dla %s nie mogło znaleźć jego źródła",
    "Sharing %s failed, because the file could not be found in the file cache" : "Współdzielenie %s nie powiodło się, ponieważ plik nie może zostać odnaleziony w buforze plików",
    "Could not find category \"%s\"" : "Nie można odnaleźć kategorii \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "W nazwach użytkowników dozwolone są wyłącznie następujące znaki: \"a-z\", \"A-Z\", \"0-9\", oraz \"_.@-\"",
    "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
    "A valid password must be provided" : "Należy podać prawidłowe hasło",
    "The username is already being used" : "Ta nazwa użytkownika jest już używana",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Brak sterowników bazy danych (sqlite, mysql or postgresql).",
    "Cannot write into \"config\" directory" : "Nie można zapisać do katalogu \"config\"",
    "Cannot write into \"apps\" directory" : "Nie można zapisać do katalogu \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Można to zwykle rozwiązać przez %sdodanie serwerowi www uprawnień zapisu do katalogu apps%s lub wyłączenie appstore w pliku konfiguracyjnym.",
    "Cannot create \"data\" directory (%s)" : "Nie można utworzyć katalogu \"data\" (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Można to zwykle rozwiązać przez <a href=\"%s\" target=\"_blank\">dodanie serwerowi www uprawnień zapisu do katalogu głównego</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Problemy z uprawnieniami można zwykle naprawić  przez %sdodanie serwerowi www uprawnień zapisu do katalogu głównego%s.",
    "Setting locale to %s failed" : "Nie udało się zmienić języka na %s",
    "Please install one of these locales on your system and restart your webserver." : "Proszę zainstalować jedno z poniższych locale w Twoim systemie i uruchomić ponownie serwer www.",
    "Please ask your server administrator to install the module." : "Proszę poproś administratora serwera aby zainstalował ten moduł.",
    "PHP module %s not installed." : "Moduł PHP %s nie jest zainstalowany.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dzieje się tak prawdopodobnie przez cache lub akcelerator taki jak Zend OPcache lub eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Moduły PHP zostały zainstalowane, ale nadal brakuje ich na liście?",
    "Please ask your server administrator to restart the web server." : "Poproś administratora serwera o restart serwera www.",
    "PostgreSQL >= 9 required" : "Wymagany PostgreSQL >= 9",
    "Please upgrade your database version" : "Uaktualnij wersję bazy danych",
    "Error occurred while checking PostgreSQL version" : "Wystąpił błąd podczas sprawdzania wersji PostgreSQL",
    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Upewnij się, że PostgreSQL jest w wersji co najmniej 9 lub sprawdź log by uzyskać więcej informacji na temat błędu",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, żeby ukryć zawartość katalogu przed innymi użytkownikami.",
    "Data directory (%s) is readable by other users" : "Katalog danych (%s) jest możliwy do odczytania przez innych użytkowników",
    "Data directory (%s) is invalid" : "Katalog danych (%s) jest nieprawidłowy",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Sprawdź, czy katalog danych zawiera plik \".ocdata\".",
    "Could not obtain lock type %d on \"%s\"." : "Nie można uzyskać blokady typu %d na \"%s\"."
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
